@@ -4,9 +4,13 @@
 ##
 ## PySol -- a Python Solitaire game
 ##
+## Copyright (C) 2003 Markus Franz Xaver Johannes Oberhumer
+## Copyright (C) 2002 Markus Franz Xaver Johannes Oberhumer
+## Copyright (C) 2001 Markus Franz Xaver Johannes Oberhumer
 ## Copyright (C) 2000 Markus Franz Xaver Johannes Oberhumer
 ## Copyright (C) 1999 Markus Franz Xaver Johannes Oberhumer
 ## Copyright (C) 1998 Markus Franz Xaver Johannes Oberhumer
+## All Rights Reserved.
 ##
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -144,8 +148,8 @@ class Options:
         else:
             self.tabletile_name = None
         #
-##        c = "Oxymoron"
-        c = "Standard"
+        c = "Oxymoron"
+##        c = "Standard"
         if 0 < sw < 800 or 0 < sh < 600:
             c = "2000"
 ##        elif sw >= 1024 and sh >= 768 and sd > 8:
@@ -168,7 +172,7 @@ class Options:
     # not changeable options
     def setConstants(self):
         self.win_animation = 1
-        self.toolbar_relief = 0
+        self.toolbar_relief = 1
         self.dragcursor = 1
         self.magnetic_mouse = 0             # doesn't work yet anyway
         self.magnetic_mouse_time = 2.0      # seconds
@@ -423,7 +427,6 @@ class Application:
             try:
                 game = tmpgame._loadGame(self.fn.holdgame, self)
             except:
-                if 1 or self.debug: traceback.print_exc()           #bundle#
                 game = None
             if game:
                 if game.id == self.opt.game_holded and game.gstats.holded:
@@ -476,7 +479,6 @@ class Application:
                         self.opt.game_holded = self.game.id
                     except: pass
                 self.freeGame()
-                self.dumpMem("after freeGame")                      #bundle#
                 #
                 if self.nextgame.id <= 0:
                     break
@@ -603,7 +605,6 @@ class Application:
 
     # debug
     def dumpMem(self, info=""):
-#%ifndef BUNDLE
         return
         if info: print "App.dumpMem: " + info
         print "freeGame:\n"; dumpmem(); print
@@ -615,7 +616,6 @@ class Application:
         #if 1 and cyclops: cyclops.show_sccs()
         #if 1 and cyclops: cyclops.show_cycles()
         if 1 and cyclops: cyclops.clear()
-#%endif
         pass
 
 
@@ -779,7 +779,6 @@ class Application:
             self.updateCardset(id, update=update)
             r = 1
         except (Exception, TclError, UnpicklingError), ex:
-            if 1 or self.debug: traceback.print_exc()               #bundle#
             cs.error = 1
             # restore settings
             self.nextgame.cardset = self.cardset
@@ -893,42 +892,6 @@ class Application:
     def requestCompatibleCardsetSize(self):
         # we don't need this check any longer now that we have a ScrolledCanvas
         return 0
-#%if 0
-        game, gi = self.game, self.game.gameinfo
-        sw, sh = self.top.winfo_screenwidth(), self.top.winfo_screenheight()
-        if sw - game.width >= 0 and sh - game.height >= 32:
-            return 0
-        #
-        cs, cs_update_flag = self.getCompatibleCardset(gi, None)
-        if cs is self.cardset:
-            if cs_update_flag & 8:
-                # current cardset was explicitly allowed for this gameid
-                return 0
-            cs = None
-        self.wm_save_state()
-        self.wm_withdraw()
-        if cs is not None:
-            self.loadCardset(cs, update=1)
-            return 1
-        #
-        t = self.checkCompatibleCardsetType(gi, self.cardset)
-        d = MfxDialog(self.top, title="Incompatible "+CARDSET, bitmap="warning",
-                      text="The currently selected "+CARDSET+"\n" + self.cardset.name
-                        + "\n\nis too large for the game\n"
-                        + gi.name + "\n\nPlease increase your screen resolution\nor select a smaller "+CARDSET+".",
-                      strings=("Select "+CARDSET+"...", "Continue"), default=0)
-        if d.status != 0:
-            return -1
-        if d.button == 1:
-            # "Continue" -> remember the cardset for this game
-            self.updateCardset(self.game.id, update=8)
-            return 0
-        cs = self.__selectCardsetDialog(t)
-        if cs is None:
-            return -1
-        self.loadCardset(cs, id=self.game.id, update=9)
-        return 1
-#%endif
 
     def __selectCardsetDialog(self, t):
         key = self.cardset.index
@@ -955,6 +918,8 @@ class Application:
             cardset = self.opt.cardset
             if hasattr(opt, "version_tuple") and hasattr(opt, "cardset"):
                 merge_dict(cardset, opt.cardset)
+            if hasattr(opt, "player"):
+                self.opt.player = ustr(opt.player)   # opt.player can be unicode
             merge_dict(self.opt.__dict__, opt.__dict__)
             self.opt.cardset = cardset
         self.opt.setConstants()
@@ -1070,9 +1035,7 @@ class Application:
                 except Exception, ex:
                     print "Error loading plugin " + n + ": " + str(ex)
                     sys.stdout.flush()
-                    if 1 or self.debug: traceback.print_exc()       #bundle#
                 except:
-                    if 1 or self.debug: traceback.print_exc()       #bundle#
                     pass
                 sys.path = p
 
@@ -1180,7 +1143,6 @@ class Application:
         try:
             dirs = dirs + manager.getRegistryDirs(self, ("PySol_Cardsets", "Cardsets"))
         except:
-            traceback.print_exc()                                   #bundle#
             pass
         ##print dirs
         found, t = [], {}
@@ -1210,7 +1172,6 @@ class Application:
                                 if os.path.isfile(f1) and os.path.isfile(f2):
                                     found.append(cs)
                         except:
-                            if self.debug: traceback.print_exc()    #bundle#
                             pass
             except EnvError, ex:
                 pass
@@ -1232,7 +1193,6 @@ class Application:
         try:
             dirs = dirs + manager.getRegistryDirs(self, "Tiles")
         except:
-            traceback.print_exc()                                   #bundle#
             pass
         ##print dirs
         s = "((\\" + string.join(IMAGE_EXTENSIONS, ")|(\\") + "))$"
@@ -1334,7 +1294,6 @@ class Application:
         try:
             dirs = dirs + manager.getRegistryDirs(self, "Music")
         except:
-            traceback.print_exc()                                   #bundle#
             pass
         ##print dirs
         ext_re = re.compile(r"\.((it)|(mod)|(mp3)|(pym)|(s3m)|(xm))$", re.I)
