@@ -4,9 +4,13 @@
 ##
 ## PySol -- a Python Solitaire game
 ##
+## Copyright (C) 2003 Markus Franz Xaver Johannes Oberhumer
+## Copyright (C) 2002 Markus Franz Xaver Johannes Oberhumer
+## Copyright (C) 2001 Markus Franz Xaver Johannes Oberhumer
 ## Copyright (C) 2000 Markus Franz Xaver Johannes Oberhumer
 ## Copyright (C) 1999 Markus Franz Xaver Johannes Oberhumer
 ## Copyright (C) 1998 Markus Franz Xaver Johannes Oberhumer
+## All Rights Reserved.
 ##
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -351,7 +355,6 @@ class Game:
         # let's go
         self.moves.state = self.S_INIT
         self.startGame()
-#%ifndef BUNDLE
         if self.gameinfo.si.game_flags & GI.GT_OPEN:
             if self.s.talon:
                 assert len(self.s.talon.cards) == 0
@@ -359,7 +362,6 @@ class Game:
                 if stack.is_visible:
                     for c in stack.cards:
                         assert c.face_up
-#%endif /* BUNDLE */
         self.startMoves()
         for stack in self.allstacks:
             stack.updateText()
@@ -716,8 +718,9 @@ class Game:
                 if v is None:
                     if tb: tb.updateText(player="Player\n")
                     continue
-                if type(v) is types.StringType:
+                if type(v) in types.StringTypes:
                     if tb:
+                        v = ustr(v)
                         if self.app.opt.toolbar_size:
                             tb.updateText(player="Player\n" + v)
                         else:
@@ -755,17 +758,17 @@ class Game:
         if self.app.audio:
             self.app.audio.stopSamplesLoop()
 
-    def startDealSample(self):
+    def startDealSample(self, loop=999999):
         a = self.app.opt.animations
         if a and not self.preview:
             self.canvas.update_idletasks()
         if self.app.audio and self.app.opt.sound:
             if a in (1, 2, 5):
-                self.playSample("deal01", priority=100, loop=1)
+                self.playSample("deal01", priority=100, loop=loop)
             elif a == 3:
-                self.playSample("deal04", priority=100, loop=1)
+                self.playSample("deal04", priority=100, loop=loop)
             elif a == 4:
-                self.playSample("deal08", priority=100, loop=1)
+                self.playSample("deal08", priority=100, loop=loop)
 
 
     #
@@ -1595,14 +1598,9 @@ class Game:
     def playOneDemoMove(self, demo):
         if self.moves.index > 2000:
             # we're probably looping because of some bug in the hint code
-            print "loop", self.id, self.moves.index                 #bundle#
             return 1
-        if self.moves.index > 500:                                  #bundle#
-            print "loop", self.id, self.moves.index                 #bundle#
-            return 1                                                #bundle#
         sleep = demo.sleep
         if self.app.debug:
-            if 0 and self.moves.index > 10: return 1                #bundle#
             if not self.top.winfo_ismapped():
                 sleep = -1.0
         # first try to deal cards to the Waste (unless there was a forced move)
@@ -1917,7 +1915,6 @@ class Game:
             self._dumpGame(p, bookmark=2)
             bm = (file.getvalue(), self.moves.index)
         except:
-            if 0 or self.app.debug: traceback.print_exc()           #bundle#
             pass
         else:
             self.gsaveinfo.bookmarks[n] = bm
@@ -1943,7 +1940,6 @@ class Game:
             # save state for undoGotoBookmark
             self.setBookmark(-1, confirm=0)
         except:
-            if 0 or self.app.debug: traceback.print_exc()           #bundle#
             del self.gsaveinfo.bookmarks[n]
             self.setCursor(cursor=self.app.top_cursor)
         else:
@@ -1972,19 +1968,16 @@ class Game:
             game = self._loadGame(filename, self.app)
             game.gstats.holded = 0
         except AssertionError, ex:
-            if 0 or self.app.debug: traceback.print_exc()           #bundle#
             self.updateMenus()
             self.setCursor(cursor=self.app.top_cursor)
             d = MfxDialog(self.top, title="Load game error", bitmap="error",
                           text="Error while loading game.\n\nProbably the game file is damaged,\nbut this could also be a bug you might want to report.")
         except (Exception, UnpicklingError), ex:
-            if 0 or self.app.debug: traceback.print_exc()           #bundle#
             self.updateMenus()
             self.setCursor(cursor=self.app.top_cursor)
             d = MfxExceptionDialog(self.top, ex, title="Load game error",
                                    text="Error while loading game")
         except:
-            if 0 or self.app.debug: traceback.print_exc()           #bundle#
             self.updateMenus()
             self.setCursor(cursor=self.app.top_cursor)
             d = MfxDialog(self.top, title="Load game error", bitmap="error",
@@ -2009,7 +2002,6 @@ class Game:
         try:
             self._saveGame(filename, binmode)
         except Exception, ex:
-            if 0 or self.app.debug: traceback.print_exc()          #bundle#
             self.setCursor(cursor=self.app.top_cursor)
             d = MfxExceptionDialog(self.top, ex, title="Save game error",
                                    text="Error while saving game")
