@@ -4,9 +4,13 @@
 ##
 ## PySol -- a Python Solitaire game
 ##
+## Copyright (C) 2003 Markus Franz Xaver Johannes Oberhumer
+## Copyright (C) 2002 Markus Franz Xaver Johannes Oberhumer
+## Copyright (C) 2001 Markus Franz Xaver Johannes Oberhumer
 ## Copyright (C) 2000 Markus Franz Xaver Johannes Oberhumer
 ## Copyright (C) 1999 Markus Franz Xaver Johannes Oberhumer
 ## Copyright (C) 1998 Markus Franz Xaver Johannes Oberhumer
+## All Rights Reserved.
 ##
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -197,7 +201,7 @@ class GI:
             41, 42, 43, 58, 59, 92, 93, 94, 95, 96,
             100, 105, 111, 112, 113, 130, 200, 201,
         )),
-        
+
         ### KDE Patience 0.7.3 from KDE 1.1.2 (we have 6 out of 9 games)
         ##("KDE Patience 0.7.3", (2, 7, 8, 18, 256, 903,)),
 
@@ -422,7 +426,6 @@ class GameManager:
             raise GameInfoException, "duplicate game ID " + str(gi.id)
         if self.__all_gamenames.has_key(gi.name):
             raise GameInfoException, "duplicate game name " + str(gi.id) + ": " + game.name
-#%ifndef BUNDLE
         if 1:
             for id, game in self.__all_games.items():
                 if gi.gameclass is game.gameclass:
@@ -430,7 +433,6 @@ class GameManager:
         for n in gi.altnames:
             if self.__all_gamenames.has_key(n):
                 raise GameInfoException, "duplicate altgame name " + str(gi.id) + ": " + n
-#%endif
         if gi.si.game_flags & GI.GT_XORIGINAL:
             return
         if 1 and (206 <= gi.id <= 236): ### and bundle & 1:
@@ -512,18 +514,10 @@ def registerGame(gameinfo):
 def loadGame(modname, filename, plugin=1):
     ##print "load game", modname, filename
     GAME_DB.loading_plugin = plugin
-#%ifdef BUNDLE
-    if os.name == "nt":
-        # we do not load plugins under Windows because of security reasons
-        #$unbundle#return
-        pass
-    #$unbundle#execfile(filename, globals(), globals())
-#%else
     if sys.modules.has_key("gamedb"):
         # unbundled
         module = imp.load_source(modname, filename)
     else:
         # bundled
         execfile(filename, globals(), globals())
-#%endif
 
