@@ -205,7 +205,7 @@ class GroundForADivorce(RelaxedSpider):
     RowStack_Class = StackWrapper(Spider_RowStack, mod=13)
 
     def createGame(self):
-        Spider.createGame(self, playcards=22)
+        RelaxedSpider.createGame(self, playcards=22)
 
     def startGame(self):
         for i in range(4):
@@ -222,7 +222,7 @@ class GrandmothersGame(RelaxedSpider):
     Layout_Method = Layout.harpLayout
 
     def createGame(self):
-        Spider.createGame(self, playcards=22)
+        RelaxedSpider.createGame(self, playcards=22)
 
     def startGame(self):
         for i in range(5):
@@ -292,7 +292,7 @@ class Rachel(RelaxedSpider):
     RowStack_Class = RK_RowStack
 
     def createGame(self):
-        Spider.createGame(self, waste=1, rows=6, texts=1)
+        RelaxedSpider.createGame(self, waste=1, rows=6, texts=1)
 
     def startGame(self):
         self.startDealSample()
@@ -312,7 +312,7 @@ class Scorpion(RelaxedSpider):
     RowStack_Class = StackWrapper(Scorpion_RowStack, base_rank=KING)
 
     def createGame(self):
-        Spider.createGame(self, rows=7, playcards=20)
+        RelaxedSpider.createGame(self, rows=7, playcards=20)
 
     def startGame(self):
         for i in (4, 4, 4, 0, 0, 0):
