@@ -4,9 +4,13 @@
 ##
 ## PySol -- a Python Solitaire game
 ##
+## Copyright (C) 2003 Markus Franz Xaver Johannes Oberhumer
+## Copyright (C) 2002 Markus Franz Xaver Johannes Oberhumer
+## Copyright (C) 2001 Markus Franz Xaver Johannes Oberhumer
 ## Copyright (C) 2000 Markus Franz Xaver Johannes Oberhumer
 ## Copyright (C) 1999 Markus Franz Xaver Johannes Oberhumer
 ## Copyright (C) 1998 Markus Franz Xaver Johannes Oberhumer
+## All Rights Reserved.
 ##
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -67,8 +71,8 @@ def helpAbout(app, timeout=0, sound=1):
     d = AboutDialog(app.top, title="About " + PACKAGE, timeout=timeout,
                text=PACKAGE+"\n" + t +
                     "Version " + VERSION + "\n\n" +
-                    "Copyright (C) 1998, 1999, 2000, 2001 Markus F.X.J. Oberhumer\n" +
-###                    "markus@oberhumer.com\n\n" +
+                    "Copyright (C) 1998, 1999, 2000, 2001, 2002, 2003\nMarkus F.X.J. Oberhumer\n" +
+###                    "<markus@oberhumer.com>\n\n" +
                     "All Rights Reserved.\n\n" +
                     PACKAGE+" is free software distributed under the terms\n" +
                     "of the GNU General Public License\n\n" +
@@ -91,7 +95,7 @@ def helpAboutSimple(app, timeout=0, sound=1):
     d = MfxDialog(app.top, title="About " + PACKAGE, timeout=timeout,
                text=PACKAGE+"\n" + t +
                     "Version " + VERSION + "\n\n" +
-                    "Copyright (C) 1998, 1999, 2000, 2001\nMarkus F.X.J. Oberhumer\n" +
+                    "Copyright (C) 1998, 1999, 2000, 2001, 2002, 2003\nMarkus F.X.J. Oberhumer\n" +
                     "\nFor more information about this application visit\n" +
                     PACKAGE_URL,
                image=app.gimages.logos[2],
@@ -115,6 +119,7 @@ def helpCredits(app, timeout=0, sound=1):
                     "T. Kirk for lots of contributed games and cardsets\n" +
                     "Carl Larsson for the background music\n" +
                     "The Gnome AisleRiot team for parts of the documentation\n" +
+                    "Natascha\n" +
                     "\n" +
                     "The Python, " + t + "SDL & Linux crews\nfor making this program possible",
                image=app.gimages.logos[3], image_side="right",
