@@ -4,10 +4,13 @@
 ##
 ## PySol -- a Python Solitaire game
 ##
+## Copyright (C) 2003 Markus Franz Xaver Johannes Oberhumer
+## Copyright (C) 2002 Markus Franz Xaver Johannes Oberhumer
 ## Copyright (C) 2001 Markus Franz Xaver Johannes Oberhumer
 ## Copyright (C) 2000 Markus Franz Xaver Johannes Oberhumer
 ## Copyright (C) 1999 Markus Franz Xaver Johannes Oberhumer
 ## Copyright (C) 1998 Markus Franz Xaver Johannes Oberhumer
+## All Rights Reserved.
 ##
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -35,7 +38,6 @@
 import sys, os, operator, re, string, time, types, htmlentitydefs
 import traceback
 
-#%ifndef BUNDLE
 try:
     from cPickle import Pickler, Unpickler, UnpicklingError
 except ImportError:
@@ -48,7 +50,6 @@ except:
 if os.name == "mac":
     import macfs, MACFS
 win32api = None
-#%endif
 
 from mfxtools import *
 
@@ -187,12 +188,10 @@ class Struct:
     def __str__(self):
         return str(self.__dict__)
 
-#%ifndef BUNDLE
     def __setattr__(self, key, value):
         if not self.__dict__.has_key(key):
             raise AttributeError, key
         self.__dict__[key] = value
-#%endif
 
     def addattr(self, **kw):
         for key in kw.keys():
@@ -309,9 +308,7 @@ def spawnv(file, args=()):
     if not (mode & 0100):
         return 0
     #
-    if os.name == "nt":
-        return win32_spawnv(file, args)
-    elif os.name == "posix":
+    if os.name == "posix":
         pid = os.fork()
         if pid == -1:
             raise os.error, "fork failed"
@@ -391,9 +388,7 @@ def spawnSystemSoundMixer(query=0):
     if query:
         return __SOUND_MIXER is not None
     MIXERS = ()
-    if os.name == "nt":
-        MIXERS = (("sndvol32.exe", None),)
-    elif os.name == "posix":
+    if os.name == "posix":
         MIXERS = (("kmix", None), ("gmix", None),)
     for name, args in MIXERS:
         try:
@@ -447,7 +442,6 @@ def openURL(url):
 # // memory debugging
 # ************************************************************************/
 
-#%ifndef BUNDLE
 
 def dumpmem(dump_all_objects=1):
     var = {}
@@ -490,14 +484,12 @@ def dumpmem(dump_all_objects=1):
         print "%7d %-25s %s" % (count, varname, valuestr)
     print "%7d ---TOTAL---" % (sum)
 
-#%endif
 
 
 # /***********************************************************************
 # // debugging
 # ************************************************************************/
 
-#%ifndef BUNDLE
 
 def callername():
     try:
@@ -514,5 +506,4 @@ def callerglobals():
 def uplevel(name):
     print __name__, callerglobals()[name], callerglobals()["__name__"]
 
-#%endif
 
