@@ -4,9 +4,13 @@
 ##
 ## PySol -- a Python Solitaire game
 ##
+## Copyright (C) 2003 Markus Franz Xaver Johannes Oberhumer
+## Copyright (C) 2002 Markus Franz Xaver Johannes Oberhumer
+## Copyright (C) 2001 Markus Franz Xaver Johannes Oberhumer
 ## Copyright (C) 2000 Markus Franz Xaver Johannes Oberhumer
 ## Copyright (C) 1999 Markus Franz Xaver Johannes Oberhumer
 ## Copyright (C) 1998 Markus Franz Xaver Johannes Oberhumer
+## All Rights Reserved.
 ##
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -35,6 +39,7 @@ import os, re, string, sys, time, types
 import traceback
 
 from mfxtools import *
+
 import thread
 import pysolsoundserver
 
@@ -207,8 +212,8 @@ class AbstractAudioClient:
 class PysolSoundServerModuleClient(AbstractAudioClient):
     def startServer(self):
         # use the module
-        self.audiodev = pysolsoundserver
         try:
+            self.audiodev = pysolsoundserver
             self.audiodev.init()
             self.server = 1         # success - see also tk/menubar.py
         except:
@@ -217,11 +222,13 @@ class PysolSoundServerModuleClient(AbstractAudioClient):
             self.audiodev = None
 
     def cmd(self, cmd):
-        self.audiodev.cmd(cmd)
+        return self.audiodev.cmd(cmd)
 
     # connect to server
     def _connectServer(self):
-        self.cmd("protocol 4")
+        r = self.cmd("protocol 6")
+        if r != 0:
+            return 0
         if 0 and self.app.debug:
             self.cmd("debug 1")
         return 1
@@ -260,9 +267,10 @@ class PysolSoundServerModuleClient(AbstractAudioClient):
         if self.audiodev is None or not self.app:
             return
         try:
+            loop = 999999
             for music in music_list:
                 if music.absname:
-                    self.cmd("queuemus '%s' %d %d %d %d" % (music.absname, music.index, 0, 0, music.volume))
+                    self.cmd("queuemus '%s' %d %d %d %d" % (music.absname, music.index, 0, loop, music.volume))
             self.cmd("startqueue")
         except:
             if traceback: traceback.print_exc()
@@ -319,3 +327,4 @@ class Win32AudioClient(AbstractAudioClient):
         flags = a.SND_NODEFAULT | a.SND_PURGE
         a.PlaySound(None, flags)
 
+
