@@ -4,9 +4,13 @@
 ##
 ## PySol -- a Python Solitaire game
 ##
+## Copyright (C) 2003 Markus Franz Xaver Johannes Oberhumer
+## Copyright (C) 2002 Markus Franz Xaver Johannes Oberhumer
+## Copyright (C) 2001 Markus Franz Xaver Johannes Oberhumer
 ## Copyright (C) 2000 Markus Franz Xaver Johannes Oberhumer
 ## Copyright (C) 1999 Markus Franz Xaver Johannes Oberhumer
 ## Copyright (C) 1998 Markus Franz Xaver Johannes Oberhumer
+## All Rights Reserved.
 ##
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -145,7 +149,9 @@ class LCRandom64(PysolRandom):
     MAX_SEED = 0xffffffffffffffffL  # 64 bits
 
     def str(self, seed):
-        s = repr(long(seed))[:-1]
+        s = repr(long(seed))
+        if s[-1:] == "L":
+            s = s[:-1]
         s = "0"*(20-len(s)) + s
         return s
 
@@ -235,12 +241,12 @@ def constructRandom(s):
     s = re.sub(r"[\s\#\-\_\.\,]", "", string.lower(s))
     if not s:
         return (None, None)
+    gameid = None
     if 1 and len(s) in (12, 16):
         # check if this an old WHRandrom seed
         if re.search(r"[^0-9a-f]", s):
             raise ValueError, s
         ss = s
-        gameid = None
         if len(s) == 16:
             gameid = string.atoi(s[:4], 16)
             ss = s[4:]
@@ -249,7 +255,6 @@ def constructRandom(s):
         z = string.atoi(ss[ 8:12], 16)
         if 0 < x < 30269 and 0 < y < 30307 and 0 < z < 30323:
             return gameid, WHRandom((x, y, z))
-    gameid = None
     if re.search(r"[^0-9]", s):
         raise ValueError, s
     seed = string.atol(s)
@@ -262,7 +267,6 @@ def constructRandom(s):
 # //
 # ************************************************************************/
 
-#%ifndef BUNDLE
 
 def random_main(args):
     # check the WHRandom pack/unpack code
@@ -283,5 +287,4 @@ def random_main(args):
 if __name__ == "__main__":
     sys.exit(random_main(sys.argv))
 
-#%endif
 
