@@ -4,9 +4,13 @@
 ##
 ## PySol -- a Python Solitaire game
 ##
+## Copyright (C) 2003 Markus Franz Xaver Johannes Oberhumer
+## Copyright (C) 2002 Markus Franz Xaver Johannes Oberhumer
+## Copyright (C) 2001 Markus Franz Xaver Johannes Oberhumer
 ## Copyright (C) 2000 Markus Franz Xaver Johannes Oberhumer
 ## Copyright (C) 1999 Markus Franz Xaver Johannes Oberhumer
 ## Copyright (C) 1998 Markus Franz Xaver Johannes Oberhumer
+## All Rights Reserved.
 ##
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -125,15 +129,12 @@ class ResourceManager:
         try:
             if dir:
                 dir = os.path.normpath(dir)
-                if os.name == "nt":
-                    dir = os.path.normcase(dir)
                 if dir and os.path.isdir(dir) and not dir in result:
                     result.append(dir)
         except EnvError, ex:
             pass
 
     def _addRegistryKey(self, result, hkey, subkey):
-        KEY_READ = 0x20019
         k = None
         try:
             k = win32api.RegOpenKeyEx(hkey, subkey, 0, KEY_READ)
@@ -180,7 +181,6 @@ class ResourceManager:
                     else:
                         self._addDir(result, os.path.join(dir, s))
                 except EnvError, ex:
-                    if app.debug and traceback: traceback.print_exc() #bundle#
                     pass
         if app.debug >= 2:
             print "getSearchDirs", env, search, "->", result
@@ -189,9 +189,6 @@ class ResourceManager:
     def getRegistryDirs(self, app, categories):
         if not win32api:
             return []
-        # we don't require the big win32con module
-        HKEY_CURRENT_USER = 0x80000001
-        HKEY_LOCAL_MACHINE = 0x80000002
         #
         vendors = ("Markus Oberhumer", "",)
         versions = (VERSION, "",)
