@@ -4,10 +4,13 @@
 ##
 ## PySol -- a Python Solitaire game
 ##
+## Copyright (C) 2003 Markus Franz Xaver Johannes Oberhumer
+## Copyright (C) 2002 Markus Franz Xaver Johannes Oberhumer
 ## Copyright (C) 2001 Markus Franz Xaver Johannes Oberhumer
 ## Copyright (C) 2000 Markus Franz Xaver Johannes Oberhumer
 ## Copyright (C) 1999 Markus Franz Xaver Johannes Oberhumer
 ## Copyright (C) 1998 Markus Franz Xaver Johannes Oberhumer
+## All Rights Reserved.
 ##
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -51,10 +54,8 @@ class _HideableCard_1(AbstractCard):
         if stack is self.hide_stack:
             return
         if self.hide_stack:
-            assert self.hide_x != 0 or self.hide_y != 0             #bundle#
             hx, hy = stack.hide_x - self.hide_x, stack.hide_y - self.hide_y
         else:
-            assert self.hide_x == 0 and self.hide_y == 0            #bundle#
             hx, hy = stack.hide_x, stack.hide_y
         ####self.item.move(hx, hy)
         item = self.item
