@@ -4,10 +4,13 @@
 ##
 ## PySol -- a Python Solitaire game
 ##
+## Copyright (C) 2003 Markus Franz Xaver Johannes Oberhumer
+## Copyright (C) 2002 Markus Franz Xaver Johannes Oberhumer
 ## Copyright (C) 2001 Markus Franz Xaver Johannes Oberhumer
 ## Copyright (C) 2000 Markus Franz Xaver Johannes Oberhumer
 ## Copyright (C) 1999 Markus Franz Xaver Johannes Oberhumer
 ## Copyright (C) 1998 Markus Franz Xaver Johannes Oberhumer
+## All Rights Reserved.
 ##
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -85,6 +88,10 @@ class MfxMenubar(Tkinter.Menu):
             path = str(self._w) + "." + name
             if self.addPath:
                 self.addPath(path, self, self.n, cnf.get("menu"))
+            if os.name == "posix":
+                pass
+##              cnf["relief"] = "groove"
+##                cnf["activeforeground"] = "#ff0000"
         Tkinter.Menu.add(self, itemType, cnf)
         self.n = self.n + 1
 
@@ -93,6 +100,10 @@ class MfxMenu(MfxMenubar):
     def __init__(self, master, label, underline=None, **kw):
         name, label, label_underline = self.labeltoname(label)
         kwdefault(kw, name=name)
+        if 1 and os.name == "posix":
+            pass
+##            kw["relief"] = "groove"
+##            kw["activeborderwidth"] = 1
         apply(MfxMenubar.__init__, (self, master,), kw)
         if underline is None:
             underline = label_underline
@@ -141,7 +152,12 @@ class PysolMenubar(PysolMenubarActions):
 
     def _createMenubar(self):
         MfxMenubar.addPath = self._addPath
-        self.__menubar = MfxMenubar(self.top, name="menubar")
+        kw = { "name": "menubar" }
+        if 1 and os.name == "posix":
+            pass
+            kw["relief"] = "groove"
+            kw["activeborderwidth"] = 1
+        self.__menubar = apply(MfxMenubar, (self.top,), kw)
 
         # init keybindings
         bind(self.top, "<KeyPress>", self._keyPressHandler)
@@ -284,22 +300,14 @@ class PysolMenubar(PysolMenubarActions):
         if bundle & 4 == 0:
             menu.add_command(label="&License terms", command=self.mHelpLicense)
             menu.add_command(label="What's &new ?", command=self.mHelpNews)
-            if os.name == "nt":
-                menu.add_separator()
-                menu.add_command(label=PACKAGE+" &Web Site", command=self.mHelpWebSite)
         menu.add_separator()
         menu.add_command(label="&About "+PACKAGE+"...", command=self.mHelpAbout)
 
-        if os.name == "mac":
-            menu = self._createMenu("Apple")
-            menu.add_command(label="About "+PACKAGE+"...", command=self.mHelpAbout)
-            menu.add_command(label=PACKAGE+" help", command=self.mHelp)
 
         MfxMenubar.addPath = None
 
         ### FIXME: all key bindings should be *added* to keyPressHandler
         ctrl = "Control-"
-        if os.name == "mac": ctrl = "Command-"
         self._bindKey("",   "n", self.mNewGame)
         self._bindKey("",   "g", self.mSelectGameDialog)
         self._bindKey("",   "v", self.mSelectGameDialogWithPreview)
@@ -391,11 +399,12 @@ class PysolMenubar(PysolMenubarActions):
 
 
     # utility
-    def _createMenu(self, label, tearoff=0):
+    def _createMenu(self, label):
         # It took me hours to find out how to place the help-menu
         # on the right side of the menubar. Finally I discovered
         # that there seems to be some magic with the widget name...
-        if os.name == "posix":
+        tearoff = 0
+        if os.name == "nt":
             tearoff = 1
         menu = MfxMenu(self.__menubar, label, tearoff=tearoff, underline=-1)
         return menu
@@ -655,7 +664,6 @@ class PysolMenubar(PysolMenubarActions):
         if PACKAGE == "PySol":
             if os.name == "posix":
                 strings, default = (None, "Load", "Cancel", "Info...",), 1
-            strings, default = (None, "Load", "Cancel", "Info...", "Config..."), 1   #bundle#
             pass
         t = CARDSET
         key = self.app.nextgame.cardset.index
