@@ -4,10 +4,13 @@
 ##
 ## PySol -- a Python Solitaire game
 ##
+## Copyright (C) 2003 Markus Franz Xaver Johannes Oberhumer
+## Copyright (C) 2002 Markus Franz Xaver Johannes Oberhumer
 ## Copyright (C) 2001 Markus Franz Xaver Johannes Oberhumer
 ## Copyright (C) 2000 Markus Franz Xaver Johannes Oberhumer
 ## Copyright (C) 1999 Markus Franz Xaver Johannes Oberhumer
 ## Copyright (C) 1998 Markus Franz Xaver Johannes Oberhumer
+## All Rights Reserved.
 ##
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -324,7 +327,7 @@ class AllGames_StatsDialog(MfxDialog):
         a = PysolStatsFormatter(self.app)
         writer = self.CanvasWriter(self.canvas, self.font, self.CHAR_H)
         if not a.writeStats(writer, player, header):
-            writer.p("No entries for player " + str(player) + "\n")
+            writer.p("No entries for player " + ustr(player) + "\n")
         destruct(writer)
         destruct(a)
 
@@ -370,12 +373,12 @@ class AllGames_StatsDialog(MfxDialog):
             x, y = 1, self.y
             p = self._pstats_text
             h = 0
-            h = max(h, p(x    , y, anchor="nw", text=str(t1)))
-            h = max(h, p(x+200, y, anchor="ne", text=str(t2)))
-            h = max(h, p(x+250, y, anchor="ne", text=str(t3)))
-            h = max(h, p(x+300, y, anchor="ne", text=str(t4)))
-            h = max(h, p(x+350, y, anchor="ne", text=str(t5)))
-            self.pstats_perc(x+372, y, str(t5))
+            h = max(h, p(x    , y, anchor="nw", text=ustr(t1)))
+            h = max(h, p(x+200, y, anchor="ne", text=ustr(t2)))
+            h = max(h, p(x+250, y, anchor="ne", text=ustr(t3)))
+            h = max(h, p(x+300, y, anchor="ne", text=ustr(t4)))
+            h = max(h, p(x+350, y, anchor="ne", text=ustr(t5)))
+            self.pstats_perc(x+372, y, ustr(t5))
             self.y = self.y + h
             self.gameid = None
 
@@ -456,7 +459,7 @@ class FullLog_StatsDialog(AllGames_StatsDialog):
         a = PysolStatsFormatter(self.app)
         writer = self.CanvasWriter(self.canvas, self.font, self.CHAR_H)
         if not a.writeFullLog(writer, player, header):
-            writer.p("No log entries for " + str(player) + "\n")
+            writer.p("No log entries for " + ustr(player) + "\n")
         destruct(a)
 
     def initKw(self, kw):
@@ -473,7 +476,7 @@ class SessionLog_StatsDialog(FullLog_StatsDialog):
         a = PysolStatsFormatter(self.app)
         writer = self.CanvasWriter(self.canvas, self.font, self.CHAR_H)
         if not a.writeSessionLog(writer, player, header):
-            writer.p("No current session log entries for " + str(player) + "\n")
+            writer.p("No current session log entries for " + ustr(player) + "\n")
         destruct(a)
 
     def initKw(self, kw):
