@@ -4,10 +4,13 @@
 ##
 ## PySol -- a Python Solitaire game
 ##
+## Copyright (C) 2003 Markus Franz Xaver Johannes Oberhumer
+## Copyright (C) 2002 Markus Franz Xaver Johannes Oberhumer
 ## Copyright (C) 2001 Markus Franz Xaver Johannes Oberhumer
 ## Copyright (C) 2000 Markus Franz Xaver Johannes Oberhumer
 ## Copyright (C) 1999 Markus Franz Xaver Johannes Oberhumer
 ## Copyright (C) 1998 Markus Franz Xaver Johannes Oberhumer
+## All Rights Reserved.
 ##
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -97,7 +100,6 @@ oEEBEQ4qJKggAQA7"""))
         try:
             self.top.grab_set()
         except Tkinter.TclError:
-            print "*** Grab failed ***"                             #bundle#
             pass
         if timeout > 0:
             self.timer = after(self.top, timeout, self.mTimeout)
@@ -603,7 +605,6 @@ class MfxScrolledCanvas:
 # //
 # ************************************************************************/
 
-#%ifndef BUNDLE
 
 def tkwidget_main(args):
     from tkutil import wm_withdraw
@@ -626,4 +627,3 @@ if __name__ == "__main__":
     import sys
     sys.exit(tkwidget_main(sys.argv))
 
-#%endif
