@@ -4,10 +4,13 @@
 ##
 ## PySol -- a Python Solitaire game
 ##
+## Copyright (C) 2003 Markus Franz Xaver Johannes Oberhumer
+## Copyright (C) 2002 Markus Franz Xaver Johannes Oberhumer
 ## Copyright (C) 2001 Markus Franz Xaver Johannes Oberhumer
 ## Copyright (C) 2000 Markus Franz Xaver Johannes Oberhumer
 ## Copyright (C) 1999 Markus Franz Xaver Johannes Oberhumer
 ## Copyright (C) 1998 Markus Franz Xaver Johannes Oberhumer
+## All Rights Reserved.
 ##
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -37,6 +40,7 @@ import os, sys, string, types, Tkinter
 # PySol imports
 if __name__ == "__main__":                                          #bundle#
     import pysoltk                                                  #bundle#
+from mfxtools import ustr
 from mfxutil import destruct
 from util import IMAGE_EXTENSIONS
 from actions import PysolToolbarActions
@@ -54,7 +58,8 @@ from tkwidget import MfxTooltip
 # ************************************************************************/
 
 class _MfxToolbar:
-    def __init__(self, top, relief=0):
+    def __init__(self, top, relief=1):
+        relief = 1
         self.top = top
         self.button_bg = None
         self.__setRelief(relief)
@@ -158,15 +163,15 @@ class _MfxToolbar:
 # ************************************************************************/
 
 class PysolToolbar(_MfxToolbar, PysolToolbarActions):
-    def __init__(self, top, dir, size, relief=0):
+    def __init__(self, top, dir, size, relief=1):
         _MfxToolbar.__init__(self, top, relief)
         PysolToolbarActions.__init__(self)
         self.dir = dir
         self.size = size
         self._createButton("new",     self.mNewGame, tooltip="New game")
-        self._createButton("open",    self.mOpen   , tooltip="Open a \nsaved game")
-        self._createSeparator()
         self._createButton("restart", self.mRestart, tooltip="Restart the \ncurrent game")
+        self._createSeparator()
+        self._createButton("open",    self.mOpen   , tooltip="Open a \nsaved game")
         self._createButton("save",    self.mSave,    tooltip="Save game")
         self._createSeparator()
         self._createButton("undo",    self.mUndo,    tooltip="Undo last move")
@@ -179,14 +184,12 @@ class PysolToolbar(_MfxToolbar, PysolToolbarActions):
         self._createButton("quit",    self.mQuit,     tooltip="Quit PySol")
         self._createSeparator(width=20, relief=Tkinter.FLAT)
         ##self._createLabel("moves", padx=8, tooltip="Number of moves\nin this game")
-        self._createLabel("player",  padx=8, tooltip="Change name of\ncurrent player")
+        self._createLabel("player",  padx=8, tooltip="Player options")
         self.player_label.bind("<1>",self.mOptPlayerOptions)
         ##self.player_label.bind("<3>",self.mOptPlayerOptions)
         self.popup = None
         self.frame.bind("<1>", self.clickHandler)
         self.frame.bind("<3>", self.rightclickHandler)
-        self.frame.bind("<2>", self.middleclickHandler)             #bundle#
-        self.frame.bind("<Control-1>", self.middleclickHandler)     #bundle#
 
     # Change the look of the frame to match the platform look
     def _initFrame(self):
@@ -295,7 +298,7 @@ class PysolToolbar(_MfxToolbar, PysolToolbarActions):
     def updateText(self, **kw):
         for name in kw.keys():
             label = getattr(self, name + "_label")
-            label["text"] = str(kw[name])
+            label["text"] = ustr(kw[name])
 
     def updateImages(self, dir, size):
         if dir == self.dir and size == self.size:
@@ -349,7 +352,6 @@ class PysolToolbar(_MfxToolbar, PysolToolbarActions):
 # //
 # ************************************************************************/
 
-#%ifndef BUNDLE
 
 class TestToolbar(PysolToolbar):
     def __init__(self, top, args):
@@ -375,5 +377,4 @@ def toolbar_main(args):
 if __name__ == "__main__":
     sys.exit(toolbar_main(sys.argv))
 
-#%endif
 
